# `testpypirpaciorek` - My Simple Project

* Opt1
* Opt2
* Opt3

## install

~~~python
pip install testpypirpaciorek
~~~

### Usage

~~~python
from testpypirpaciorek.m_mod_rp import name as n
from testpypirpaciorek.m_mod_rp import get_numpy_arr 
>>> n("Name","surname")
Name Surname
>>> get_numpy_arr([1,2,3,4,5])\
[1,2,3,4,5]
~~~